---
title: 상점·계정관리
category: 관리자콘솔 (관리자콘솔 사용 가이드) > 상점·계정관리 > 상점·계정관리
seo:
  title: 상점·계정관리
  description: 사업자 정보, 관리자 계정 관리, 하위 상점 관리 등 관리자콘솔이 제공하는 상점/계정관리를 위한 기능들을 확인해보세요.
  keywords:
    - 계정관리
    - 상점관리
    - 상점·계정관리
    - 관리자콘솔
    - 포트원
tags:
  - 공통
  - 상점정보
  - 관리자콘솔
pgCompanies:
  - 공통
searchTags:
  - 하위상점
  - 관리자권한
  - 마케팅수신
  - 로그아웃
  - 회원탈퇴
  - 2차인증
  - 비밀번호변경
  - 계정변경
  - 이메일변경
  - 계정권한
---

### **상점 · 계정 관리**

#### **1.사업자정보**



- **로그인 계정** : 현재 로그인하고 계시는 계정 주소
- **계정 권한** : 로그인하신 계정에 부여된 권한
- **계정정보 관리**



- **이메일 변경** : 로그인하시는 메일주소 변경가능 (이미 가입된 계정을 중복 가입 불가)
- **비밀번호 변경** : 비밀번호 변경가능
- **2차 인증** : 관리자콘솔 2차인증(OTP)등록 가능
- **마케팅 수신 동의 변경**
- **회원 탈퇴** : <Highlight text="Admin(Owner) 계정은 삭제 시, 연결된 상점 전체도 함께 삭제되니 주의해 주세요" />\
  (탈퇴한 계정의 경우  30일이내에 변경/가입이 불가 합니다. )



- **로그아웃** : 좌측 하단 계정을 클릭 후 ‘로그아웃’

#### **2. 관리자 계정 관리**

- 해당 메뉴에서는 권한별 로그인 가능한 계정을 추가/삭제/변경 하실 수 있습니다.



- 권한은 admin, dev, manage, read only 로 4가지이며, 기능은 다음과 같이 구분됩니다.

<Indent level="1">

- Admin : 모든 내용 조회/수정 가능 (최대 1개 계정 추가가능)
- Dev : 결제연동 메뉴 수정, 내역 조회 (최대 10개 계정 추가가능)
- Manager : 모든 내역 조회 및 수정, 리포트 조회, 계정 관리 수정 가능 (계정 갯수 제한 없음)
- Read only : 내역 조회, 리포트 조회 가능 (계정 갯수 제한 없음)

</Indent>

#### 3. **하위 상점 관리 (선택)**

- 상위 상점과 하위 상점이 구분되어있는 형태의 서비스이실 경우, 하나의 상위 상점에서 하위 상점의 연동 채널/결제내역을 통합 관리하실 수 있습니다. \
  (ex : A상점(상위)에서 지역별 지점이 존재하는 경우, 하위상점에 \[강남 지점],\[삼성 지점],\[역삼 지점] 등으로 구분하여 설정가능)



- **돋보기 기능** : 등록된 하위상점을 검색하여 조회가능
- **연결된 계정 권한**
  - 하위상점에 특정 메일계정 연동가능 (연결된 계정은 해당 하위상점의 내역만 조회가능)
  - 하위상점에 매핑되는 계정은 Manager 혹은 Read only 권한으로만 가능합니다.



- **상점명** : 하위상점을 구분할 수 있는 이름
- **사용할 결제채널 선택** : 하위상점으로 연동하고자 하는 PG사와 상점정보를 선택
  - 결제연동 메뉴에서 연동이 필요한 채널을 먼저 설정하신 후 하위상점과 연결합니다.
- **서비스 URL :** 하위상점의 연동페이지 URL 입력
- **담당자명** : 하위상점의 담당자님 성함
- **담당자 휴대폰번호 :** 하위상점의 담당자님 휴대폰번호
- **티어 코드** : 영문(대문자)와 숫자3자리로 티어코드 설정
  - 하위상점 연동시 티어코드로 구분합니다.
- **결제알림(Webhook) 설정** : 상위상점의 웹훅 URL과 동일하게 설정하실 경우 체크
